@@ -61,24 +61,19 @@ class GitIssuePublisher(Publisher):
         try:
             _auth = Auth.Token(_api_key)
             self.__github = Github(auth=_auth)
-            self.repo = repo
+            self.repo = self.__github.get_repo(repo)
             self.branch = branch
             self.sha = sha
-            self.user = self.__github.get_user().login
+            # Get the repository
+
+            # Get the commit details based on the SHA
+            commit = repo.get_commit(self.sha)
+
+            # Set the user who made the push (the author of the commit)
+            self.user = commit.author.login
         except GithubException as e:
             raise Exception(f"Error initializing GitHub client: {e}")
 
-    def __get_repo(self):
-        """
-        Retrieves the GitHub repository object.
-
-        :return: The GitHub repository object.
-        """
-        try:
-            return self.__github.get_repo(self.repo)
-        except GithubException as e:
-            raise Exception(f"Error retrieving repository {self.repo}: {e}")
-
 
     def publish(self, data):
         """
@@ -94,9 +89,9 @@ class GitIssuePublisher(Publisher):
                                                         message=data['message']['adherence']['score'],
                                                         vulnerability=data['codeVulnerability']['score'])
             existing_issue.edit(body=updated_body)
-            existing_issue.create_comment(self.generate_report(data))
+            comment = existing_issue.create_comment(self.generate_report(data))
 
-            return
+            return existing_issue.number, comment.id
         except GithubException as e:
             raise Exception(f"Error publishing issue: {e}")
  
@@ -109,12 +104,11 @@ class GitIssuePublisher(Publisher):
         :return: The existing or newly created issue.
         """
         try:
-            repo = self.__get_repo()
 
             ############################################################################
             # Search for the issue by title
             # Esta parte del codigo es la mas costosa... investigar como optimizar
-            issues = repo.get_issues(state='all')  # Fetch all issues (open and closed)
+            issues = self.repo.get_issues(state='all')  # Fetch all issues (open and closed)
             existing_issue = next((issue for issue in issues if issue.title == title), None)
             ############################################################################
 
@@ -127,7 +121,7 @@ class GitIssuePublisher(Publisher):
 
             # If no issue is found, create a new one
             # This creates the first comment... this is where we are going to have the summary built with markdown
-            new_issue = repo.create_issue(title=title, body=body, assignee=self.user)
+            new_issue = self.repo.create_issue(title=title, body=body, assignee=self.user)
             return new_issue
 
         except GithubException as e:
@@ -138,7 +132,7 @@ class GitIssuePublisher(Publisher):
             f"## Commit Review Summary [{self.sha}]",
             "| **Author** | **Provided Message** | **Generated Message** | **Adherence Score** | **Comment** |",
             "|------------|----------------------|-----------------------|---------------------|-------------|",
-            f"| {self.user} | '{data['message']['provided']}' | '{data['message']['generated']}' | {data['message']['adherence']['score']} {data['message']['adherence']['emoji']} | *{data['message']['adherence']['comment']}* |",
+            f"| @{self.user} | '{data['message']['provided']}' | '{data['message']['generated']}' | {data['message']['adherence']['score']} {data['message']['adherence']['emoji']} | *{data['message']['adherence']['comment']}* |",
             "\n### Code Complexity",
             "| **Complexity Comment** |",
             "|------------------------|",
